Module toolset

Module toolset 

Structs

BasicToolset
A simple toolset that wraps a static list of tools with optional filtering.
FilteredToolset
A toolset wrapper that filters tools from an inner toolset using a predicate.
MergedToolset
A toolset that merges tools from multiple inner toolsets into one.
PrefixedToolset
A toolset wrapper that prefixes all tool names from an inner toolset.

Functions

string_predicate
Creates a predicate that allows only tools with names in the provided list.