pub struct BasicToolset { /* private fields */ }Expand description
A simple toolset that wraps a static list of tools with optional filtering.
Implementations
Sourceimpl BasicToolset
impl BasicToolset
Sourcepub fn new(name: impl Into<String>, tools: Vec<Arc<dyn Tool>>) -> Self
pub fn new(name: impl Into<String>, tools: Vec<Arc<dyn Tool>>) -> Self
Create a new BasicToolset with the given name and tools.
Sourcepub fn with_predicate(self, predicate: ToolPredicate) -> Self
pub fn with_predicate(self, predicate: ToolPredicate) -> Self
Set a predicate to filter which tools are returned.