UrlContextTool

Struct UrlContextTool 

pub struct UrlContextTool;
UrlContext is a built-in tool that is automatically invoked by Gemini models to fetch and analyze content from URLs. The tool operates internally within the model and does not require or perform local code execution.

Implementations

Source

impl UrlContextTool

pub fn new() -> Self

Create a new UrlContextTool.