Structs
- Basic
Toolset - A simple toolset that wraps a static list of tools with optional filtering.
- Filtered
Toolset - A toolset wrapper that filters tools from an inner toolset using a predicate.
- Merged
Toolset - A toolset that merges tools from multiple inner toolsets into one.
- Prefixed
Toolset - A toolset wrapper that prefixes all tool names from an inner toolset.
Functions
- string_
predicate - Creates a predicate that allows only tools with names in the provided list.